@@ -12,6 +12,7 @@
 #include <QKeySequence>
 #include <QList>
 #include <QWidget>
+#include <memory>
 
 class KActionCollection;
 class KShortcutWidgetPrivate;
@@ -78,13 +79,9 @@ public Q_SLOTS:
      */
     void applyStealShortcut();
 
-private:
-    Q_PRIVATE_SLOT(d, void priKeySequenceChanged(const QKeySequence &))
-    Q_PRIVATE_SLOT(d, void altKeySequenceChanged(const QKeySequence &))
-
 private:
     friend class KShortcutWidgetPrivate;
-    KShortcutWidgetPrivate *const d;
+    std::unique_ptr<KShortcutWidgetPrivate> const d;
 };
 
-#endif //KSHORTCUTWIDGET_H
+#endif // KSHORTCUTWIDGET_H
